SlidingWidget class

Inheritance

Constructors

SlidingWidget({Key? key, double height = 70, double width = 300, Color backgroundColor = Colors.white, Color? backgroundColorEnd, Color foregroundColor = Colors.blueAccent, Color iconColor = Colors.white, BoxShadow? shadow, Widget child = const Icon(Icons.chevron_right, color: Colors.white, size: 35), String label = "Slide to proceed", TextStyle? labelStyle, required VoidCallback action, VoidCallback? onTapDown, VoidCallback? onTapUp, BorderRadius? foregroundShape, BorderRadius? backgroundShape, bool stickToEnd = false})
const

Properties

action → VoidCallback
This is the callback function of the widget when tapped - VoidCallback
final
backgroundColor → Color
This is the background color of the sliding widget - Color
final
backgroundColorEnd → Color?
This is the background color of the widget when slided - Color
final
backgroundShape → BorderRadius?
This is the background shape / border of the widget - BorderRadius
final
child → Widget
This is the child widget for the sliding widget - Widget
final
foregroundColor → Color
This is the foreground color of the widget - Color
final
foregroundShape → BorderRadius?
This is the foreground shape / border of the widget - BorderRadius
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
This is the height of the widget - double
final
iconColor → Color
This is the icon color of the widget - Color
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → String
This is the display text for the widget - String
final
labelStyle → TextStyle?
This is the text style for the display / button text of the sliding widget - TextStyle
final
onTapDown → VoidCallback?
This is the callback function of the widget when tapped down - VoidCallback
final
onTapUp → VoidCallback?
This is the callback function of the widget when tapped up- VoidCallback
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadow → BoxShadow?
This is the shadow effect of the widget - BoxShadow
final
stickToEnd → bool
This is the condtion check for sticking to the end on completion of the widget - bool
final
width → double
This is the width of the widget - double
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited